CATEGORY_TREE = {
    'food-and-drink': [
        'restaurant',
        'food-court',
        'fast-food',
        'coffee-shop',
        'pub',
    ],
    'healthcare': [
        'hospital',
        'clinic',
        'doctor',
        'pharmacy',
    ],
    'education': [
        'school',
        'college',
        'university',
        'kindergarten',
    ],
    'public-transport': [
        'bus-stop',
        'railway-station',
    ],
    'shopping': [
        'supermarket',
        'mall',
        'convenience-store',
    ],
    'green-spaces': [
        'park',
        'garden',
        'nature-reserve',
    ],
    'landform': [
        'beach',
    ],
    'fitness': [
        'gym',
        'fitness-station',
        'sports-centre',
    ],
}
